####################
lsst-projectmeta-kit
####################

.. image:: https://img.shields.io/pypi/v/lsst-projectmeta-kit.svg
   :target: https://pypi.python.org/pypi/lsst-projectmeta-kit
   :alt: Python Package Index
.. image:: https://img.shields.io/travis/lsst-sqre/lsst-projectmeta-kit.svg
   :target: https://travis-ci.org/lsst-sqre/lsst-projectmeta-kit
   :alt: Travis CI build status

**lsst-projectmeta-kit is a Python toolkit for extracting and transforming metadata about LSST's code and documentation projects, and loading it into the LSST projectmeta database.**

This project is related to LSST Project Meta, an experimental project to gather LSST information artifacts from across the web, and make them discoverable through a single API.
Extract/transform/load workflows can use this library to create LSST JSON-LD (linked data) resources stored in our Project Meta database.

lsst-projectmeta-kit is developed by **LSST**, the Large Synoptic Survey Telescope.
Learn more at `www.lsst.org <https://www.lsst.org>`_.

License
=======

lsst-projectmeta-kit is MIT licensed. See `LICENSE <./LICENSE>`_.
